<template>
  <nuxt-link  :to="'/account/advertise/show/' + data.id"  class="position-relative" :class="{'d-none': !meta.loaded}">
    <img src="/packages/vije_fa.png" v-if="typeof data.packages.find((item) => item.slug === 'special') !== 'undefined'" class="position-absolute" style="width: 30px;top: 0;left: 0;z-index: 10;" alt="">
    <div class="card horizontal-card h-100 min-h-160-px shadow-sm">
      <div class="card-body p-0">
        <div class="row h-100">
          <div class="col-6 py-3">
            <div
                class="px-3 h-100 d-flex align-items-start justify-content-start flex-column"
                :class="[{'text-end': isRTL},{'text-start': !isRTL}]"
            >
              <h5 class="card-title font-size-14">{{ data?.title.substr(0, 45) }}</h5>
              <div class="mt-auto">
                <p class="card-text text-muted mb-1 font-size-14">
                  <template v-if="data.price == 0">
                    {{ t('advertise.agreed') }}
                  </template>
                  <template v-else>
                    <span class="fw-bold" :class="isRTL ? 'ms-1' : 'me-1'">
                      {{ $helper?.getCurrency(data.price) }}
                    </span>
                    <span class="font-size-10">{{ $t('reservations.currency') }}</span>
                  </template>
                </p>
                <small class="text-muted font-size-10">
                  {{ data.date }} | {{ data.province?.title }}, {{ data.city?.title }}
                </small>
                <span class="status-badge bg-secondary-light font-size-10 text-secondary py-0" v-if="step">
                  <i class="icon icon-regular-clock text-secondary font-size-16 mt-1 ms-1"></i>
                  {{ data.step.title }}
                </span>
              </div>
            </div>
          </div>

          <div
          class="col-6 p-0 d-flex align-items-center justify-content-end"
          :class="[{'ps-0': isRTL},{'pe-0': !isRTL}]"
      >
        <div class="p-3 d-flex align-items-center justify-content-center w-100 h-100 position-relative">
          <div
              ref="imageRef"
              class="w-100 shadow-sm rounded-1 w-100 h-120-px h-100 bg-cover bg-center"
              :class="{ 'lazy-placeholder': !loadedImage }"
              :style="loadedImage ? `background-image: url('${data.image !== '' ? data.image : '/add.jpg'}')` : ''"
          ></div>
          <span class="position-absolute text-default font-size-12" v-if="typeof data.packages.find((item) => item.slug === 'ai') !== 'undefined'" style="right: 0;top: 0;transform: rotate(90deg) translateX(65px) translateY(-50px)">
            <i class="icon icon-filled-diamond text-default font-size-15" style="vertical-align: -5px;"></i>
            هوش مشتری یاب
          </span>

        </div>

      </div>
        </div>
      </div>
    </div>
  </nuxt-link>

  <!-- شِیمر در حالت لودینگ -->
  <a href="javascript:;" :class="{ 'd-none': meta.loaded }">
    <div class="card horizontal-card h-100 min-h-160-px shadow-sm">
      <div class="card-body p-0">
        <div class="row h-100">
          <div class="col-6 py-3" :class="[{'ps-0': isRTL},{'pe-0': !isRTL}]">
            <div class="px-3 h-100 d-flex align-items-start justify-content-start flex-column">
              <shimmer height="20" class="my-2 rounded"/>
              <div class="mt-auto">
                <p class="card-text text-muted mb-1 font-size-14">
                  <shimmer height="15" class="my-2 rounded"/>
                </p>
                <shimmer height="10" class="my-2 rounded"/>
              </div>
            </div>
          </div>
          <div class="col-6" :class="[{'ps-0': isRTL},{'pe-0': !isRTL}]">
            <div class="p-3">
              <shimmer height="120" class="my-2 rounded"/>
            </div>
          </div>
        </div>
      </div>
    </div>
  </a>
</template>

<script setup>
import { useI18n } from 'vue-i18n'
import { ref, reactive, onMounted, onBeforeUnmount, computed } from 'vue'

const { locale, t } = useI18n()
const { $helper } = useNuxtApp()

const props = defineProps({
  data: {
    type: Object,
    required: true
  },
  click: {
    type: Boolean,
    default: true
  },
  step: {
    type: Boolean,
    default: false
  }
})

const isRTL = computed(() => ['fa', 'ar'].includes(locale.value))

// وضعیت لودینگ کلی
const meta = reactive({
  loaded: false
})

onMounted(() => {
  setTimeout(() => {
    meta.loaded = true
  }, 100)
})

// Lazy Loading برای تصویر بک‌گراند
const imageRef = ref(null)
const loadedImage = ref(false)
let observer = null

onMounted(() => {
  observer = new IntersectionObserver(
      ([entry]) => {
        if (entry.isIntersecting) {
          loadedImage.value = true
          observer.disconnect()
        }
      },
      {
        root: null,
        threshold: 0.1
      }
  )

  if (imageRef.value) {
    observer.observe(imageRef.value)
  }
})

onBeforeUnmount(() => {
  if (observer) {
    observer.disconnect()
  }
})
</script>

<style scoped>
.bg-cover {
  background-size: cover;
}
.bg-center {
  background-position: center;
}
.lazy-placeholder {
  background-color: #eee;
}
</style>